Start Romagna
Description: Start, la nuova grande realtà del trasporto pubblico in Romagna.

# Fai una Segnalazione

# Per noi, i reclami e i suggerimenti rappresentano uno strumento importante per conoscere meglio i nostri clienti e la percezione che hanno dei servizi erogati.

I reclami e i suggerimenti esprimono infatti le motivazioni di insoddisfazione dei clienti e permettono di contribuire a migliorare il servizio partendo dalla soluzione delle problematiche segnalate o dai suggerimenti degli utenti.

Ad ogni reclamo viene attivata una procedura di verifica delle criticità indicate. A questo fine, è necessario compilare il modulo sottostante con le proprie generalità complete di recapito e con ogni particolare utile ad identificare con precisione i termini e le circostanze dell’accaduto (data dell’evento, ora, luogo, linea, ecc.).

Start Romagna si impegna a fornire al cliente una risposta scritta (lettera, SMS, e-mail) o telefonica nei tempi previsti dalla Carta della Mobilità del bacino di competenza. Per fare una segnalazione scritta o telefonica, è possibile rivolgersi alla sede ufficiale del proprio bacino.

I campi contrassegnati con * sono obbligatori.

Nel caso non si volesse procedere alla compilazione del modulo online, è possibile scaricare il modulo dedicato al reclamo o al suggerimento qui.

Vorrei
Fare un reclamo Dare un suggerimento

#### I tuoi dati

Nome*
Cognome *
Email*
Residente a*
Provincia*
Telefono / Cellulare
Acconsento a essere contattato tramite SMS

#### Dati Relativi al disservizio

Data*
Ora*
Località*
Fermata n°*
Linea n°*
Direzione*
Targa / Matricola Bus
Autista
Tipologia del disservizio*
Descrizione del disservizio*

#### Allega documentazione

Formato DOC, PDF, JPG o PNG, max. 2MB
Formato DOC, PDF, JPG o PNG, max. 2MB

#### Informativa e consenso al trattamento dei dati personali

Start Romagna, in qualità di titolare dei suoi dati personali, la informa che ai sensi dell’art. 13 del D. Lgs. 196 del 30/06/2003 i suoi dati saranno trattati nel rispetto della normativa citata. Lei gode dei diritti previsti dal citato decreto e le vengono riconosciuti i diritti di cui all’art. 7 che potranno essere esercitati rivolgendosi al Titolare o al Responsabile del trattamento dei dati di Start Romagna.

Acconsento al trattamento dei miei dati*

## Recapiti per segnalazioni scritte o telefoniche

- #### Sede Operativa di Ravenna

  Piazza Farini (interno Stazione FS) - 48121 Ravenna
  Tel 199 11 55 77
  Fax 0544 451508

- #### Sede Operativa di Forlì-Cesena

  Via A. Volta n. 9 - 47122 Forlì
  Tel 199 11 55 77
  Fax 0543 787280

- #### Sede Operativa di Rimini

  Via Carlo Alberto Dalla Chiesa, 38 - 47923 Rimini
  Tel 199 11 55 77
  Fax 0541 300821

- #### Posta elettronica (tutti i Bacini)

  servizioclienti@startromagna.it

## Area Riservata Start&You

Username o Email
Password
Ricordami Password dimenticata?

Non hai ancora un account?
Scopri i vantaggi del mondo Start

Registrati
Adesso